Introduction
------------

Protocol arrange message conversation between two users.
Each chat has 4 phases:

#. Create chat
#. Join chat
#. Conversation
#. Exit chat

.. toctree::
   :maxdepth: 2
   :titlesonly:

   Create chat
   Join chat by code
   Conversation
   Exit   
